<?php 


/**
 * Fired during plugin activation
 * 
 * @link              https://profiles.wordpress.org/chirag967/
 * @since             1.0.0
 * @package           Global_Content_Manager
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * 
 * */
class GLCM_Admin {
    /**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
    private $plugin_name;


    /**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;
    
    /**
     * Initialize the class and set its properties.
     * 
     * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version ) {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }
    /**
     * Register the stylesheets for the admin area.
     */
    public function enqueue_styles() {
        global $post_type;
        if ( $post_type === 'glcm' ) {
            wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/admin.css', array(), $this->version, 'all' );
        }
    }

    /**
     * Register the JavaScript for the admin area.
     */
    public function enqueue_scripts() {
        global $post_type;
        if ( $post_type === 'glcm' ) {
            wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/admin.js', array( 'jquery' ), $this->version, false );
        }
    }
    /**
	 * Initialize plugin
	 *
	 * @since    1.0.0
	 */
	public function plugin_init() {
        $labels = array(
            'name'                  => _x('Global Content Manager', 'Post Type General Name', 'global-content-manager'),
            'singular_name'         => _x('Global Content', 'Post Type Singular Name', 'global-content-manager'),
            'menu_name'             => __('Global Content Manager', 'global-content-manager'),
            'name_admin_bar'        => __('Global Content', 'global-content-manager'),
            'parent_item_colon'     => __('Parent Item:', 'global-content-manager'),
            'all_items'             => __('All Global Content', 'global-content-manager'),
            'add_new_item'          => __('Add New Global Content', 'global-content-manager'),
            'add_new'               => __('Add New', 'global-content-manager'),
            'new_item'              => __('New Global Content', 'global-content-manager'),
            'edit_item'             => __('Edit Global Content', 'global-content-manager'),
            'update_item'           => __('Update Global Content', 'global-content-manager'),
            'view_item'             => __('View Global Content', 'global-content-manager'),
            'search_items'          => __('Search Global Content', 'global-content-manager'),
            'not_found'             => __('Not found', 'global-content-manager'),
            'not_found_in_trash'    => __('Not found in Trash', 'global-content-manager'),
            'items_list'            => __('Items list', 'global-content-manager'),
            'items_list_navigation' => __('Items list navigation', 'global-content-manager'),
            'filter_items_list'     => __('Filter items list', 'global-content-manager'),
          );

          $args = array(
            'labels'                => $labels,
            'supports'              => array('title', 'editor'),
            'hierarchical'          => false,
            'public'                => false,
            'show_ui'               => true,
            'show_in_menu'          => true,
            'show_in_admin_bar'     => true,
            'show_in_nav_menus'     => true,
            'can_export'            => true,
            'has_archive'           => false,
            'show_in_rest'          => true,
            'exclude_from_search'   => false,
            'publicly_queryable'    => false,
            'capability_type'       => 'post',
            'menu_icon'             => 'dashicons-admin-generic',
          );

        register_post_type('glcm', $args);
	}

    /**
	 * Flush rewrite rules on plugin activation
	 *
	 * @since    1.0.0
	 */
	public function glcm_plugin_activate_flush_rewrite() {
		 $this->plugin_init();
		flush_rewrite_rules();
	}

    /**
	 * Define custom columns for GLCM admin table
	 *
	 * @since  1.0.0
	 */
	public function glcm_posts_columns( $columns ) {

		$columns = array(
			'cb' => $columns['cb'],
			'title' => __('Title', 'global-content-manager'),
			'slug' => __('Slug', 'global-content-manager'),
			'shortcode' => __('Shortcode', 'global-content-manager'),
			'show-preview' => __('Preview', 'global-content-manager'),
			'date' => __('Date', 'global-content-manager'),
		);
		return $columns;
	}
    /**
	 * Render custom columns for GLCM admin table
	 *
	 * @since    1.0.0
	 * @param      string    $column_name       The name column.
	 * @param      string    $post_id    The id of this GLCM post.
	 */
	public function glcm_posts_custom_columns( $column_name, $post_id ) {
        switch ($column_name) {
            case 'slug':  
                echo esc_html(get_post_field( 'post_name', get_post() ));
                
                break;
            case 'shortcode':  
                $inputID = "glcm-copyshortcode-$post_id";
                echo '<input type="text" class="glcm-copyshortcode" id="'.esc_html($inputID).'" value="[GLCM id=\''.esc_html($post_id).'\']" readOnly>';

                echo '<button class="glcm-copyshortcode-button button" onclick="glcmCopyToClipboard(this)" type="button" data-id="'.esc_html($inputID).'"> <span class="dashicons dashicons-admin-page"></span> </button>';
                break;
            case 'show-preview':
                esc_html_e('Coming soon', 'global-content-manager');
                break;
            default:
                echo '-';
        }
    }

}